
package com.mycompany.JSONTrials;

import com.mycompany.JSONTrials.jaxb.types.ContactType;
import com.mycompany.JSONTrials.jaxb.types.CountryType;
import com.mycompany.JSONTrials.jaxb.types.CustomerOrderType;
import com.mycompany.JSONTrials.jaxb.types.CustomerType;
import com.mycompany.JSONTrials.jaxb.types.DeliveryAddressType;
import com.mycompany.JSONTrials.jaxb.types.DeliveryType;
import com.mycompany.JSONTrials.jaxb.types.ItemType;
import com.mycompany.JSONTrials.jaxb.types.LineItemType;
import com.mycompany.JSONTrials.jaxb.types.OrderItemType;
import com.mycompany.JSONTrials.jaxb.types.OrderLineType;
import com.mycompany.JSONTrials.jaxb.types.OrderType;
import com.mycompany.JSONTrials.jaxb.types.OriginatorCustomerPartyType;
import com.mycompany.JSONTrials.jaxb.types.PartyNameType;
import com.mycompany.JSONTrials.jaxb.types.PartyType;
import com.mycompany.JSONTrials.jaxb.types.PostalAddressType;
import com.mycompany.JSONTrials.jaxb.types.PriceType;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;

/** Example resource class hosted at the URI path "/myresource"
 */
@Path("/orders")
public class OrderResource {
    
    /** Method processing HTTP GET requests, producing "text/plain" MIME media
     * type.
     * @return String that will be send back as a response of type "text/plain".
     */
    @GET 
    @Produces({"application/xml","application/json"})
    public OrderType bookOrder() {
        CustomerOrderType customerOrder = getCustomerOrder();
        CustomerType customer = customerOrder.getCustomer();

        OrderType orderType = new OrderType();

        // set customer details in order
        CountryType country = new CountryType();
        country.setIdentificationCode(customer.getCountryCode());

        PostalAddressType postalAddress = new PostalAddressType();
        postalAddress.setBuildingNumber(customer.getBuildingNumber());
        postalAddress.setStreetName(customer.getStreetName());
        postalAddress.setCityName(customer.getCityName());
        postalAddress.setPostalZone(customer.getPinCode());
        postalAddress.setCountry(country);

        ContactType contact = new ContactType();
        contact.setName(customer.getName());
        contact.setTelephone("9901999388");

        PartyNameType partyName = new PartyNameType();
        partyName.setName(customer.getName());

        PartyType party = new PartyType();
        party.setPartyName(partyName);
        party.setPostalAddress(postalAddress);
        party.setContact(contact);

        OriginatorCustomerPartyType originatorCustomerParty = new OriginatorCustomerPartyType();
        originatorCustomerParty.setPartyType(party);

        // set delivery address
        DeliveryAddressType deliveryAddress = new DeliveryAddressType();
        deliveryAddress.setBuildingNumber(customer.getBuildingNumber());
        deliveryAddress.setStreetName(customer.getStreetName());
        deliveryAddress.setCityName(customer.getCityName());
        deliveryAddress.setPostalZone(customer.getPinCode());
        deliveryAddress.setCountry(country);

        DeliveryType delivery = new DeliveryType();
        delivery.setDeliveryAddressType(deliveryAddress);

        // set order item
        OrderItemType orderItem = new OrderItemType();
        orderItem.setName("DummyItem1");
        orderItem.setDescription("Dummy Description for dummyItem1....");

        PriceType price = new PriceType();
        price.setBaseQuantity(100);
        price.setPriceAmount(10.00);
        price.setOrderItemType(orderItem);

        LineItemType lineItem = new LineItemType();
        lineItem.setId("1");
        lineItem.setPriceType(price);

        OrderLineType orderLine = new OrderLineType();
        orderLine.setLineItem(lineItem);

        // set order data
        orderType.setDelivery(delivery);
        orderType.setId("1");
        orderType.setOrderLine(orderLine);
       orderType.setOriginatorCustomerParty(originatorCustomerParty);

        return orderType;
    }

    private CustomerOrderType getCustomerOrder() {
        CustomerType customer = new CustomerType();
        customer.setBuildingNumber("10A");
        customer.setCityName("Bangalore");
        customer.setCountryCode("IND");
        customer.setName("Naresh");
        customer.setPinCode("560026");
        customer.setStreetName("Richmond Town");

        ItemType item = new ItemType();
        item.setItemCode("Item01");
        item.setQuantity(100);


        CustomerOrderType customerOrder = new CustomerOrderType();
        customerOrder.setCustomer(customer);
        customerOrder.setItem(item);
        return customerOrder;
    }
}
